#version 120

#include "/settings.glsl"

varying vec2 uv;
uniform sampler2D colortex0;
uniform sampler2D depthtex0;

uniform float near, far;
uniform float blindness;
uniform float darknessFactor;
uniform vec3 fogColor;
uniform int worldTime;

uniform mat4 gbufferProjectionInverse;

float smoothTransition(float time) {
    if (time >= 0.0f && time <= 1000.0f) {
        return time / 1000.0f; // Transition from 0 to 1
    } else if (time > 1000.0f && time < 12000.0f) {
        return 1.0f; // Fully enabled
    } else if (time >= 12000.0f && time <= 13000.0f) {
        return 1.0f - (time - 12000.0f) / 1000.0f; // Transition from 1 to 0
    } else {
        return 0.0f; // Fully disabled
    }
}

vec3 projectAndDivide(mat4 projectionMatrix, vec3 position){
	vec4 homPos = projectionMatrix * vec4(position, 1.0);
	return homPos.xyz / homPos.w;
}

/* DRAWBUFFERS:0 */
layout(location = 0) out vec4 color;

void main() {
	color = texture(colortex0, uv);
	
	#if FOG == 1
	float depth = texture(depthtex0, uv).r;
	if(depth == 1.0){
		return;
	}
	
	vec3 NDCPos = vec3(uv.xy, depth) * 2.0 - 1.0;
	vec3 viewPos = projectAndDivide(gbufferProjectionInverse, NDCPos);
	
	
	float distance = length(viewPos) / (far * mix(mix(1, near * 0.5, blindness), near, darknessFactor));
	float fogFactor = exp(-mix(FOG_DISTANCE, 1, blindness) * (1.0 - distance));
	
	vec3 color_sky;
	#if TI == 0
	#if GREY_WEATHER == 0
	color_sky = fogColor;
	#else
	float state = smoothTransition(worldTime);
	color_sky = mix(fogColor, vec3(0.75, 0.75, 0.76), state);
	#endif
	#else
	float state = smoothTransition(worldTime);
	color_sky = pow(mix(vec3(0.0005), vec3(0.18), state), vec3(1.0f / 2.2f));
	#endif
	
	color.rgb = mix(color.rgb, pow(color_sky, vec3(2.2f / 1.0f)), clamp(fogFactor, 0.0, 1.0));
	#endif
}
